@@ -14,11 +14,7 @@ def status(ctx, is_raw):
     profile_config = svc.client.profile.content
     profile_name = svc.client.profile_name
     if is_raw:
-        dct = {
-            'version': get_version(),
-            'profile': profile_name,
-            'profile_config': profile_config,
-        }
+        dct = {'version': get_version(), 'profile': profile_name, 'profile_config': profile_config}
         for key in ('build_info', 'app_info', 'endpoints', 'current_user'):
             dct[key] = getattr(svc, key, None)
         resp = session.get(session.url_from_endpoint('pipelines'))
