@@ -13,10 +13,7 @@ def status(ctx, is_raw):
     svc = ctx.obj.service
     profile_name = get_default_profile()
     if is_raw:
-        dct = {
-            'version': nextcodecli.get_version(),
-            'profile': profile_name,
-        }
+        dct = {'version': nextcodecli.get_version(), 'profile': profile_name}
         for key in ('build_info', 'app_info', 'endpoints', 'current_user'):
             dct[key] = getattr(svc.session, key, None)
         click.echo(dumps(dct))
